@@ -2,7 +2,10 @@
 from __future__ import print_function, unicode_literals
 
 import argparse
-import collections
+try:
+    import collections.abc as collections
+except ImportError:
+    import collections
 import locale
 import logging
 import multiprocessing
@@ -29,7 +32,12 @@ from pelican.utils import (clean_output_dir, file_watcher,
                            folder_watcher, maybe_pluralize)
 from pelican.writers import Writer
 
-__version__ = "4.0.1"
+try:
+    __version__ = __import__('pkg_resources') \
+        .get_distribution('pelican').version
+except Exception:
+    __version__ = "unknown"
+
 DEFAULT_CONFIG_NAME = 'pelicanconf.py'
 logger = logging.getLogger(__name__)
 
@@ -444,8 +452,8 @@ def get_instance(args):
 
     config_file = args.settings
     if config_file is None and os.path.isfile(DEFAULT_CONFIG_NAME):
-            config_file = DEFAULT_CONFIG_NAME
-            args.settings = DEFAULT_CONFIG_NAME
+        config_file = DEFAULT_CONFIG_NAME
+        args.settings = DEFAULT_CONFIG_NAME
 
     settings = read_settings(config_file, override=get_config(args))
 
